@@ -84,7 +84,7 @@ impl Logic for MAX31856Simulator {
     #[hdl_gen]
     fn update(&mut self) {
         // Connect the spi bus
-        self.wires.link(&mut self.spi_slave.wires);
+        SPIWiresSlave::link(&mut self.wires, &mut self.spi_slave.wires);
         // Clock the internal logic
         self.reg_ram.write_clock.next = self.clock.val();
         self.reg_ram.read_clock.next = self.clock.val();
