@@ -29,7 +29,7 @@ impl<const N: usize> MuxedADS868XSimulators<N> {
 impl<const N: usize> Logic for MuxedADS868XSimulators<N> {
     #[hdl_gen]
     fn update(&mut self) {
-        self.wires.link(&mut self.mux.from_master);
+        SPIWiresSlave::link(&mut self.wires, &mut self.mux.from_master);
         for i in 0_usize..N {
             self.adcs[i].clock.next = self.clock.val();
             SPIWiresMaster::join(&mut self.mux.to_slaves[i], &mut self.adcs[i].wires);
